@@ -52,9 +52,9 @@ select_daily_reference_data <- function(standard_df,
 
     standard_df <- standard_df %>%
     # get day of month
-      dplyr::mutate(date = lubridate::date(.data$d18O_meas_btime)) %>%
+      dplyr::mutate(date = lubridate::date(.data$timeBgn)) %>%
       dplyr::group_by(.data$date) %>%
-      dplyr::filter(.data$d18O_meas_n > min_nobs | is.na(.data$d18O_meas_n)) %>%
+      dplyr::filter(.data$dlta18OH2o.numSamp > min_nobs | is.na(.data$dlta18OH2o.numSamp)) %>%
       dplyr::slice(tail(dplyr::row_number(), 3)) %>%
       dplyr::ungroup() %>%
       dplyr::select(-"date")
